pub struct StoreParams {
pub content: String,
pub memory_type: String,
pub summary: Option<String>,
pub tags: Option<Vec<String>>,
pub importance: Option<f32>,
pub source_identifier: Option<String>,
pub organization: Option<String>,
pub project: Option<String>,
}Fields
content: Stringmemory_type: Stringsummary: Option<String>importance: Option<f32>source_identifier: Option<String>organization: Option<String>project: Option<String>Trait Implementations
Sourceimpl Debug for StoreParams
impl Debug for StoreParams
Sourceimpl<'de> Deserialize<'de> for StoreParams
impl<'de> Deserialize<'de> for StoreParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StoreParams
impl JsonSchema for StoreParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StoreParams
impl RefUnwindSafe for StoreParams
impl Send for StoreParams
impl Sync for StoreParams
impl Unpin for StoreParams
impl UnsafeUnpin for StoreParams
impl UnwindSafe for StoreParams